(*
    $Id: xml.mli,v 1.4 1999/01/12 20:25:54 lindig Exp $

    Copyright (c) 1999 Christian Lindig <lindig@ips.cs.tu-bs.de>. All
    rights reserved. See COPYING for details.
 *)

open Pp         (* defines doc type and pretty printing functions *)

(*
 * xml abstract syntax
 *) 

type name	= string
type attribute	= name * name           (* name="value" *)
type pi         = name * string list    (* processing instruction *)


type element	= Eelement  of	    name * attribute list * element 
		| Eempty    of	    name * attribute list
		| Echunk    of	    string
                | Epi       of      pi 
                | Ebreak                                (* extra breaks *)
                | Econs     of      element * element
                | Enil

type dtd_id     = DTDsys    of      string
                | DTDpub    of      string * string
               
(* 
 * dtd is incomplete - no markup type provided 
 *)
  
type dtd        = DTD       of      name * dtd_id option 

type xmldecl    = XMLDecl   of string            (* version *)
                             * bool option       (* standalone *)
                             * string option     (* encoding *) 

type prolog     = Prolog    of xmldecl option 
                             * dtd option 
                             * pi list 

type document   = XML       of prolog * element * pi list                

(* constructor functions
 *)

val (^^) :      element -> element -> element
val break :     element
val empty :     element
val chunk :     string -> element
val element :   string -> attribute list -> element -> element
val single  :   string -> attribute list -> element
val pi :        string -> string list -> element

(*
 * pretty printing for XML documents
 *)
 
val ppDoc : document -> doc
